/*
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation. Portions created by Netscape are
 * Copyright (C) 1998-2001 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s):
 *   Joe Hewitt (hewitt@netscape.com)
 */

/* ===== search.css =====================================================
  == Styles specific to the Search sidebar panel.
  ======================================================================= */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

#stopButton {
  list-style-image: url("chrome://communicator/skin/icons/loading.gif");
}

.searchpanel-outerbox {
  padding: 8px 4px 4px 4px;
}

#searchengines {
  margin: 0px;
}

/* :::: undo regular search tree selection look :::: */

treeitem[selected="true"] > .searchresult {
  background-color: transparent;
}

.searchresult-cell:hover {
  color: blue;
  text-decoration: underline;
}

/* :::::: undo boldness of button-toolbar-3 :::::: */

#saveQueryButton {
  font-weight: normal;
}

